==> TechRebornJEI-20.1.6-sources.jar: thelm/techrebornjei/addon/industrialreborn/IndustrialRebornJEI.java <==
package thelm.techrebornjei.addon.industrialreborn;

import me.munchii.industrialreborn.client.gui.GuiFluidTransposer;
import me.munchii.industrialreborn.init.IRContent;
import me.munchii.industrialreborn.init.IRRecipes;
import me.munchii.industrialreborn.recipe.FluidTransposerRecipe;
import mezz.jei.api.IModPlugin;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.registration.IGuiHandlerRegistration;
import mezz.jei.api.registration.IRecipeCatalystRegistration;
import mezz.jei.api.registration.IRecipeCategoryRegistration;
import mezz.jei.api.registration.IRecipeRegistration;
import net.minecraft.class_1799;
import net.minecraft.class_1863;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import thelm.techrebornjei.TechRebornJEI;
import thelm.techrebornjei.gui.render.RecipeClickAreaRenderable;
import thelm.techrebornjei.recipe.category.ItemFluidToItemRecipeCategory;

public class IndustrialRebornJEI implements IModPlugin {

	public static final class_2960 UID = new class_2960("techrebornjei:industrialreborn");

	public static final RecipeType<FluidTransposerRecipe> FLUID_TRANSPOSER = TechRebornJEI.createRecipeType(IRRecipes.FLUID_TRANSPOSER, FluidTransposerRecipe.class);

	@Override
	public class_2960 getPluginUid() {
		return UID;
	}

	@Override
	public void registerCategories(IRecipeCategoryRegistration registration) {
		registration.addRecipeCategories(new ItemFluidToItemRecipeCategory<>(FLUID_TRANSPOSER, class_2561.method_43471("block.industrialreborn.fluid_transposer")));
	}

	@Override
	public void registerRecipes(IRecipeRegistration registration) {
		class_1863 recipeManager = class_310.method_1551().field_1687.method_8433();
		registration.addRecipes(FLUID_TRANSPOSER, recipeManager.method_30027(IRRecipes.FLUID_TRANSPOSER));
	}

	@Override
	public void registerRecipeCatalysts(IRecipeCatalystRegistration registration) {
		registration.addRecipeCatalyst(new class_1799(IRContent.Machine.FLUID_TRANSPOSER), FLUID_TRANSPOSER);
	}

	@Override
	public void registerGuiHandlers(IGuiHandlerRegistration registration) {
		registration.addRecipeClickArea(GuiFluidTransposer.class, 158, 5, 12, 12, FLUID_TRANSPOSER);

		RecipeClickAreaRenderable.addEntry(GuiFluidTransposer.class);
	}
}

==> TechRebornJEI-20.4.6-sources.jar: thelm/techrebornjei/addon/industrialreborn/IndustrialRebornJEI.java <==
package thelm.techrebornjei.addon.industrialreborn;

import me.munchii.industrialreborn.client.gui.GuiFluidTransposer;
import me.munchii.industrialreborn.init.IRContent;
import me.munchii.industrialreborn.init.IRRecipes;
import me.munchii.industrialreborn.recipe.FluidTransposerRecipe;
import mezz.jei.api.IModPlugin;
import mezz.jei.api.recipe.RecipeType;
import mezz.jei.api.registration.IGuiHandlerRegistration;
import mezz.jei.api.registration.IRecipeCatalystRegistration;
import mezz.jei.api.registration.IRecipeCategoryRegistration;
import mezz.jei.api.registration.IRecipeRegistration;
import net.minecraft.class_1799;
import net.minecraft.class_1863;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_8786;
import thelm.techrebornjei.gui.render.RecipeClickAreaRenderable;
import thelm.techrebornjei.recipe.category.ItemFluidToItemRecipeCategory;

public class IndustrialRebornJEI implements IModPlugin {

	public static final class_2960 UID = new class_2960("techrebornjei:industrialreborn");

	public static final RecipeType<class_8786<FluidTransposerRecipe>> FLUID_TRANSPOSER = RecipeType.createFromVanilla(IRRecipes.FLUID_TRANSPOSER);

	@Override
	public class_2960 getPluginUid() {
		return UID;
	}

	@Override
	public void registerCategories(IRecipeCategoryRegistration registration) {
		registration.addRecipeCategories(new ItemFluidToItemRecipeCategory<>(FLUID_TRANSPOSER, class_2561.method_43471("block.industrialreborn.fluid_transposer")));
	}

	@Override
	public void registerRecipes(IRecipeRegistration registration) {
		class_1863 recipeManager = class_310.method_1551().field_1687.method_8433();
		registration.addRecipes(FLUID_TRANSPOSER, recipeManager.method_30027(IRRecipes.FLUID_TRANSPOSER));
	}

	@Override
	public void registerRecipeCatalysts(IRecipeCatalystRegistration registration) {
		registration.addRecipeCatalyst(new class_1799(IRContent.Machine.FLUID_TRANSPOSER), FLUID_TRANSPOSER);
	}

	@Override
	public void registerGuiHandlers(IGuiHandlerRegistration registration) {
		registration.addRecipeClickArea(GuiFluidTransposer.class, 158, 5, 12, 12, FLUID_TRANSPOSER);

		RecipeClickAreaRenderable.addEntry(GuiFluidTransposer.class);
	}
}
